==> v0.1.78-snapshot.zip: beteran-protobuf-rust/src/ss/member_bank_withdraw.rs <==
const SUBJECT: &str = "bet.beteran.ss.member_bank_withdraw";
const EVENT_SUBJECT: &str = "bet.beteran.ss_event.member_bank_withdraw";

pub const SUBJECT_CREATE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".CreateMemberBankWithdraw");
pub const SUBJECT_LIST_MEMBER_BANK_WITHDRAWS: &str =
  const_format::concatcp!(SUBJECT, ".ListMemberBankWithdraws");
pub const SUBJECT_GET_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".GetMemberBankWithdraw");
pub const SUBJECT_UPDATE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankWithdraw");
pub const SUBJECT_UPDATE_MEMBER_BANK_WITHDRAW_FOR_STATE: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankWithdrawForState");
pub const SUBJECT_DELETE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".DeleteMemberBankWithdraw");

pub const EVENT_SUBJECT_AFTER_UPDATE_MEMBER_BANK_WITHDRAW_FOR_STATE: &str =
  const_format::concatcp!(EVENT_SUBJECT, ".AfterUpdateMemberBankWithdrawForState");

/// subject = bet.beteran.ss.member_bank_withdraw.CreateMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<create_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawRequest`.
pub mod create_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub member_id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub bank_name: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub account_number: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, tag = "6")]
    pub password: ::prost::alloc::string::String,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawResponse`.
pub mod create_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.ListMemberBankWithdraws
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<list_member_bank_withdraws_request::Request>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsRequest`.
pub mod list_member_bank_withdraws_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(message, optional, tag = "1")]
    pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
    #[prost(message, repeated, tag = "2")]
    pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
    #[prost(message, optional, tag = "3")]
    pub search: ::core::option::Option<request::Search>,
  }
  /// Nested message and enum types in `Request`.
  pub mod request {
    #[derive(Clone, PartialEq, ::prost::Message)]
    pub struct Search {
      #[prost(string, optional, tag = "1")]
      pub member_id: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "2")]
      pub bank_name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "3")]
      pub name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "4")]
      pub account_number_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(uint32, optional, tag = "5")]
      pub amount: ::core::option::Option<u32>,
      #[prost(string, optional, tag = "6")]
      pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(
        enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
        optional,
        tag = "7"
      )]
      pub state: ::core::option::Option<i32>,
    }
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_withdraws_response::Result>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsResponse`.
pub mod list_member_bank_withdraws_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_withdraws:
      ::prost::alloc::vec::Vec<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.GetMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<get_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `GetMemberBankWithdrawRequest`.
pub mod get_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `GetMemberBankWithdrawResponse`.
pub mod get_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.UpdateMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawRequest`.
pub mod update_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub bank_name: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub account_number: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, tag = "6")]
    pub password: ::prost::alloc::string::String,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawResponse`.
pub mod update_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.UpdateMemberBankWithdrawForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_withdraw_for_state_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateRequest`.
pub mod update_member_bank_withdraw_for_state_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(
      enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
      tag = "2"
    )]
    pub state: i32,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateResponse`.
pub mod update_member_bank_withdraw_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.DeleteMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<delete_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawRequest`.
pub mod delete_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawResponse`.
pub mod delete_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}

/// subject = bet.beteran.ss_event.member_bank_withdraw.AfterUpdateMemberBankWithdrawForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct AfterUpdateMemberBankWithdrawForState {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub event: ::core::option::Option<after_update_member_bank_withdraw_for_state::Event>,
}
/// Nested message and enum types in `AfterUpdateMemberBankWithdrawForState`.
pub mod after_update_member_bank_withdraw_for_state {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Event {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdraw>,
  }
}

==> v0.1.82-snapshot.zip: beteran-protobuf-rust/src/ss/member_bank_withdraw.rs <==
const SUBJECT: &str = "bet.beteran.ss.member_bank_withdraw";
const EVENT_SUBJECT: &str = "bet.beteran.ss_event.member_bank_withdraw";

pub const SUBJECT_CREATE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".CreateMemberBankWithdraw");
pub const SUBJECT_LIST_MEMBER_BANK_WITHDRAWS: &str =
  const_format::concatcp!(SUBJECT, ".ListMemberBankWithdraws");
pub const SUBJECT_GET_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".GetMemberBankWithdraw");
pub const SUBJECT_UPDATE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankWithdraw");
pub const SUBJECT_UPDATE_MEMBER_BANK_WITHDRAW_FOR_STATE: &str =
  const_format::concatcp!(SUBJECT, ".UpdateMemberBankWithdrawForState");
pub const SUBJECT_DELETE_MEMBER_BANK_WITHDRAW: &str =
  const_format::concatcp!(SUBJECT, ".DeleteMemberBankWithdraw");

pub const EVENT_SUBJECT_AFTER_UPDATE_MEMBER_BANK_WITHDRAW_FOR_STATE: &str =
  const_format::concatcp!(EVENT_SUBJECT, ".AfterUpdateMemberBankWithdrawForState");

/// subject = bet.beteran.ss.member_bank_withdraw.CreateMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<create_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawRequest`.
pub mod create_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub member_id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub bank_name: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub account_number: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, tag = "6")]
    pub password: ::prost::alloc::string::String,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CreateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<create_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `CreateMemberBankWithdrawResponse`.
pub mod create_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.ListMemberBankWithdraws
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<list_member_bank_withdraws_request::Request>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsRequest`.
pub mod list_member_bank_withdraws_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(message, optional, tag = "1")]
    pub pagination: ::core::option::Option<crate::protobuf::pagination::Pagination>,
    #[prost(message, repeated, tag = "2")]
    pub sorts: ::prost::alloc::vec::Vec<crate::protobuf::pagination::Sort>,
    #[prost(message, optional, tag = "3")]
    pub search: ::core::option::Option<request::Search>,
  }
  /// Nested message and enum types in `Request`.
  pub mod request {
    #[derive(Clone, PartialEq, ::prost::Message)]
    pub struct Search {
      #[prost(string, optional, tag = "1")]
      pub member_id: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "2")]
      pub bank_name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "3")]
      pub name_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(string, optional, tag = "4")]
      pub account_number_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(uint32, optional, tag = "5")]
      pub amount: ::core::option::Option<u32>,
      #[prost(string, optional, tag = "6")]
      pub memo_like: ::core::option::Option<::prost::alloc::string::String>,
      #[prost(
        enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
        optional,
        tag = "7"
      )]
      pub state: ::core::option::Option<i32>,
    }
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct ListMemberBankWithdrawsResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<list_member_bank_withdraws_response::Result>,
}
/// Nested message and enum types in `ListMemberBankWithdrawsResponse`.
pub mod list_member_bank_withdraws_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, repeated, tag = "1")]
    pub member_bank_withdraws:
      ::prost::alloc::vec::Vec<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.GetMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<get_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `GetMemberBankWithdrawRequest`.
pub mod get_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct GetMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<get_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `GetMemberBankWithdrawResponse`.
pub mod get_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.UpdateMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawRequest`.
pub mod update_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub bank_name: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub name: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub account_number: ::prost::alloc::string::String,
    #[prost(uint32, tag = "5")]
    pub amount: u32,
    #[prost(string, tag = "6")]
    pub password: ::prost::alloc::string::String,
    #[prost(string, optional, tag = "7")]
    pub memo: ::core::option::Option<::prost::alloc::string::String>,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawResponse`.
pub mod update_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.UpdateMemberBankWithdrawForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<update_member_bank_withdraw_for_state_request::Request>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateRequest`.
pub mod update_member_bank_withdraw_for_state_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
    #[prost(
      enumeration = "crate::models::member_bank_withdraw::MemberBankWithdrawState",
      tag = "2"
    )]
    pub state: i32,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct UpdateMemberBankWithdrawForStateResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<update_member_bank_withdraw_for_state_response::Result>,
}
/// Nested message and enum types in `UpdateMemberBankWithdrawForStateResponse`.
pub mod update_member_bank_withdraw_for_state_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
/// subject = bet.beteran.ss.member_bank_withdraw.DeleteMemberBankWithdraw
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<delete_member_bank_withdraw_request::Request>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawRequest`.
pub mod delete_member_bank_withdraw_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub id: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct DeleteMemberBankWithdrawResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<delete_member_bank_withdraw_response::Result>,
}
/// Nested message and enum types in `DeleteMemberBankWithdrawResponse`.
pub mod delete_member_bank_withdraw_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {}
}

/// subject = bet.beteran.ss_event.member_bank_withdraw.AfterUpdateMemberBankWithdrawForState
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct AfterUpdateMemberBankWithdrawForState {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub event: ::core::option::Option<after_update_member_bank_withdraw_for_state::Event>,
}
/// Nested message and enum types in `AfterUpdateMemberBankWithdrawForState`.
pub mod after_update_member_bank_withdraw_for_state {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Event {
    #[prost(message, optional, tag = "1")]
    pub member_bank_withdraw:
      ::core::option::Option<crate::models::member_bank_withdraw::MemberBankWithdrawModel>,
  }
}
